On Wed, Jul 3, 2013 at 5:47 PM, Eleytherios Stamatogiannakis <estama@gmail.com> wrote:
Hello to all, and thanks for the great work on PyPy.
There remains a very problematic case in PyPy, where PyPy (tested with nightly) is around 193 times slower than CPython.
This happens when reading a file using the universal newline flag ("rU").
Are there any plans to fix this problematic case, or should we just avoid using it when running under PyPy?
Kind regards,
lefteris. _______________________________________________ pypy-dev mailing list pypy-dev@python.org http://mail.python.org/mailman/listinfo/pypy-dev
Hey. Well obviously first someone has to report the issue, which you just did. Can you please file a bug report with a standalone program that shows the behavior and put it on bugs.pypy.org? Thanks for your interest in pypy! Cheers, fijal